@@ -1,3 +1,7 @@
+import sys
+import os
+path = os.getcwd()
+sys.path.append(path)
 import gloce.func
 import gloce.area
 import gloce.interpolation
